pub struct HttpServerConfig {
pub type_: HttpType,
pub url: String,
pub headers: HashMap<String, String>,
pub proxy: bool,
}Fields
type_: HttpTypeurl: Stringheaders: HashMap<String, String>proxy: boolTrait Implementations
Sourceimpl Clone for HttpServerConfig
impl Clone for HttpServerConfig
Sourcefn clone(&self) -> HttpServerConfig
fn clone(&self) -> HttpServerConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HttpServerConfig
impl Debug for HttpServerConfig
Sourceimpl<'de> Deserialize<'de> for HttpServerConfig
impl<'de> Deserialize<'de> for HttpServerConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HttpServerConfig
impl JsonSchema for HttpServerConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for HttpServerConfig
impl PartialEq for HttpServerConfig
Sourcefn eq(&self, other: &HttpServerConfig) -> bool
fn eq(&self, other: &HttpServerConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for HttpServerConfig
impl Serialize for HttpServerConfig
impl StructuralPartialEq for HttpServerConfig