pub struct InMemoryServerConfig {
pub type_: InMemoryType,
pub args: Vec<String>,
pub input: Option<Value>,
pub proxy: bool,
}Fields
type_: InMemoryTypeargs: Vec<String>input: Option<Value>proxy: boolTrait Implementations
Sourceimpl Clone for InMemoryServerConfig
impl Clone for InMemoryServerConfig
Sourcefn clone(&self) -> InMemoryServerConfig
fn clone(&self) -> InMemoryServerConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InMemoryServerConfig
impl Debug for InMemoryServerConfig
Sourceimpl<'de> Deserialize<'de> for InMemoryServerConfig
impl<'de> Deserialize<'de> for InMemoryServerConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for InMemoryServerConfig
impl JsonSchema for InMemoryServerConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for InMemoryServerConfig
impl PartialEq for InMemoryServerConfig
Sourcefn eq(&self, other: &InMemoryServerConfig) -> bool
fn eq(&self, other: &InMemoryServerConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for InMemoryServerConfig
impl Serialize for InMemoryServerConfig
impl StructuralPartialEq for InMemoryServerConfig