pub struct SseServerConfig {
pub type_: SseType,
pub url: String,
pub headers: HashMap<String, String>,
pub proxy: bool,
}Fields
type_: SseTypeurl: Stringheaders: HashMap<String, String>proxy: boolTrait Implementations
Sourceimpl Clone for SseServerConfig
impl Clone for SseServerConfig
Sourcefn clone(&self) -> SseServerConfig
fn clone(&self) -> SseServerConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SseServerConfig
impl Debug for SseServerConfig
Sourceimpl<'de> Deserialize<'de> for SseServerConfig
impl<'de> Deserialize<'de> for SseServerConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SseServerConfig
impl JsonSchema for SseServerConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SseServerConfig
impl PartialEq for SseServerConfig
Sourcefn eq(&self, other: &SseServerConfig) -> bool
fn eq(&self, other: &SseServerConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SseServerConfig
impl Serialize for SseServerConfig
impl StructuralPartialEq for SseServerConfig