Module manager

Module manager 

Re-exports

pub use crate::status::McpServerAuthCapability;
pub use crate::status::McpServerStatus;
pub use crate::status::McpServerStatusEntry;

Structs

ElicitationRequest
ElicitationResponse
McpConnectionDetails
McpManager
Manages connections to multiple MCP servers and their tools
OAuthHandlerContext
Context passed to an OAuthHandlerFactory so the constructed handler can dispatch user-facing prompts back to the host through the MCP event channel.
UrlElicitationCompleteParams

Enums

McpClientEvent
Events emitted by MCP clients that require attention from the host (e.g. the relay or TUI). Flows through a single channel from McpManager to the consumer.

Constants

DEFAULT_PROXY_NAME

Type Aliases

OAuthHandlerFactory