McpManager

Struct McpManager 

pub struct McpManager { /* private fields */ }
Manages connections to multiple MCP servers and their tools

Implementations

Source

impl McpManager

pub fn new( event_sender: Sender<McpClientEvent>, oauth_handler_factory: Option<OAuthHandlerFactory>, ) -> Self

pub fn with_aether_home(self, aether_home: impl Into<PathBuf>) -> Self

pub fn with_oauth_credential_store( self, store: Arc<dyn OAuthCredentialStorage>, ) -> Self

pub async fn add_mcps(&mut self, servers: Vec<McpServer>) -> Result<()>

pub fn get_client_for_tool( &self, namespaced_tool_name: &str, arguments_json: &str, ) -> Result<(Arc<RunningService<RoleClient, McpClient>>, CallToolRequestParams)>

pub fn tool_definitions(&self) -> Vec<ToolDefinition>

pub fn server_instructions(&self) -> Vec<ServerInstructions>

pub fn server_statuses(&self) -> &[McpServerStatusEntry]

pub async fn authenticate_server_task( &mut self, name: &str, ) -> Result<impl Future<Output = McpConnectAttempt> + Send + 'static>

pub async fn apply_connection_attempt(&mut self, attempt: McpConnectAttempt)

pub async fn list_prompts(&self) -> Result<Vec<Prompt>>

List all prompts from all connected MCP servers with namespacing

pub async fn get_prompt( &self, namespaced_prompt_name: &str, arguments: Option<Map<String, Value>>, ) -> Result<GetPromptResult>

Get a specific prompt by namespaced name

pub async fn shutdown(&mut self)

Shutdown all servers and wait for their tasks to complete

pub async fn shutdown_server(&mut self, server_name: &str) -> Result<()>

Shutdown a specific server by name

pub async fn set_roots(&mut self, new_roots: Vec<Root>) -> Result<()>

Set the roots advertised to MCP servers.

This updates the roots and sends notifications to all connected servers that support the roots/list_changed notification.